import { SchemeName, ThemeName } from '@redux-devtools/ui';
import { REHYDRATE } from 'redux-persist';
import { CHANGE_SECTION, CHANGE_THEME, SELECT_INSTANCE, SELECT_MONITOR, UPDATE_MONITOR_STATE, LIFTED_ACTION, MONITOR_ACTION, EXPORT, TOGGLE_SYNC, TOGGLE_SLIDER, TOGGLE_DISPATCHER, TOGGLE_PERSIST, GET_REPORT_REQUEST, SHOW_NOTIFICATION, CLEAR_NOTIFICATION, UPDATE_STATE, UPDATE_REPORTS, REMOVE_INSTANCE, SET_STATE, GET_REPORT_ERROR, GET_REPORT_SUCCESS, ERROR, SET_PERSIST, CHANGE_STATE_TREE_SETTINGS, CLEAR_INSTANCES } from '../constants/actionTypes';
import { Action } from 'redux';
import { Features, State } from '../reducers/instances';
import { MonitorStateMonitorState } from '../reducers/monitor';
import { LiftedAction } from '@redux-devtools/core';
import { Data } from '../reducers/reports';
import { LiftedState } from '@redux-devtools/core';
export interface ChangeSectionAction {
    readonly type: typeof CHANGE_SECTION;
    readonly section: string;
}
export declare function changeSection(section: string): ChangeSectionAction;
interface ChangeThemeFormData {
    readonly theme: ThemeName;
    readonly scheme: SchemeName;
    readonly colorPreference: 'auto' | 'light' | 'dark';
}
interface ChangeThemeData {
    readonly formData: ChangeThemeFormData;
}
export interface ChangeThemeAction {
    readonly type: typeof CHANGE_THEME;
    readonly theme: ThemeName;
    readonly scheme: SchemeName;
    readonly colorPreference: 'auto' | 'light' | 'dark';
}
export declare function changeTheme(data: ChangeThemeData): ChangeThemeAction;
interface ChangeStateTreeSettingsFormData {
    readonly sortAlphabetically: boolean;
    readonly disableCollection: boolean;
}
interface ChangeStateTreeSettingsData {
    readonly formData: ChangeStateTreeSettingsFormData;
}
export interface ChangeStateTreeSettingsAction {
    readonly type: typeof CHANGE_STATE_TREE_SETTINGS;
    readonly sortAlphabetically: boolean;
    readonly disableCollection: boolean;
}
export declare function changeStateTreeSettings(data: ChangeStateTreeSettingsData): ChangeStateTreeSettingsAction;
export interface InitMonitorAction {
    type: '@@INIT_MONITOR';
    newMonitorState: unknown;
    update: (monitorProps: unknown, state: unknown | undefined, action: Action<string>) => unknown;
    monitorProps: unknown;
}
export interface MonitorActionAction {
    type: typeof MONITOR_ACTION;
    action: InitMonitorAction;
    monitorReducer: (monitorProps: unknown, state: unknown | undefined, action: Action<string>) => unknown;
    monitorProps: unknown;
}
export interface JumpToStateAction {
    type: 'JUMP_TO_STATE';
    index: number;
}
export interface JumpToActionAction {
    type: 'JUMP_TO_ACTION';
    actionId: number;
}
export interface PauseRecordingAction {
    type: 'PAUSE_RECORDING';
    status: boolean;
}
export interface LockChangesAction {
    type: 'LOCK_CHANGES';
    status: boolean;
}
export interface ToggleActionAction {
    type: 'TOGGLE_ACTION';
    id: number;
}
export interface RollbackAction {
    type: 'ROLLBACK';
    timestamp: number;
}
export interface SweepAction {
    type: 'SWEEP';
}
interface ReorderActionAction {
    type: 'REORDER_ACTION';
    actionId: number;
    beforeActionId: number;
}
interface ImportStateAction {
    type: 'IMPORT_STATE';
    nextLiftedState: LiftedState<unknown, Action<string>, unknown> | readonly Action<string>[];
    preloadedState?: unknown;
    noRecompute?: boolean | undefined;
}
export type DispatchAction = JumpToStateAction | JumpToActionAction | PauseRecordingAction | LockChangesAction | ToggleActionAction | RollbackAction | SweepAction | ReorderActionAction | ImportStateAction;
interface LiftedActionActionBase {
    action?: DispatchAction | string | CustomAction;
    state?: string;
    toAll?: boolean;
}
export interface LiftedActionDispatchAction extends LiftedActionActionBase {
    type: typeof LIFTED_ACTION;
    message: 'DISPATCH';
    action: DispatchAction;
    toAll?: boolean;
}
export interface LiftedActionImportAction extends LiftedActionActionBase {
    type: typeof LIFTED_ACTION;
    message: 'IMPORT';
    state: string;
    preloadedState: unknown | undefined;
}
export interface LiftedActionActionAction extends LiftedActionActionBase {
    type: typeof LIFTED_ACTION;
    message: 'ACTION';
    action: string | CustomAction;
}
export interface LiftedActionExportAction extends LiftedActionActionBase {
    type: typeof LIFTED_ACTION;
    message: 'EXPORT';
    toExport: boolean;
}
export type LiftedActionAction = LiftedActionDispatchAction | LiftedActionImportAction | LiftedActionActionAction | LiftedActionExportAction;
export declare function liftedDispatch(action: InitMonitorAction | JumpToStateAction | JumpToActionAction | LiftedAction<unknown, Action<string>, unknown>): MonitorActionAction | LiftedActionDispatchAction;
export interface SelectInstanceAction {
    type: typeof SELECT_INSTANCE;
    selected: string | number;
}
export declare function selectInstance(selected: string): SelectInstanceAction;
export interface SelectMonitorAction {
    type: typeof SELECT_MONITOR;
    monitor: string;
    monitorState?: MonitorStateMonitorState;
}
export declare function selectMonitor(monitor: string): SelectMonitorAction;
export declare function selectMonitorWithState(value: string, monitorState: MonitorStateMonitorState): SelectMonitorAction;
interface NextState {
    subTabName: string;
    inspectedStatePath?: string[];
}
export interface UpdateMonitorStateAction {
    type: typeof UPDATE_MONITOR_STATE;
    nextState: NextState;
}
export declare function selectMonitorTab(subTabName: string): UpdateMonitorStateAction;
export declare function updateMonitorState(nextState: NextState): UpdateMonitorStateAction;
export declare function importState(state: string, preloadedState?: unknown): LiftedActionImportAction;
export interface ExportAction {
    type: typeof EXPORT;
}
export declare function exportState(): ExportAction;
export declare function lockChanges(status: boolean): LiftedActionDispatchAction;
export declare function pauseRecording(status: boolean): LiftedActionDispatchAction;
export interface CustomAction {
    name: string;
    selected: number;
    args: string[];
    rest: string;
}
export declare function dispatchRemotely(action: string | CustomAction): LiftedActionActionAction;
export interface TogglePersistAction {
    type: typeof TOGGLE_PERSIST;
}
export declare function togglePersist(): TogglePersistAction;
export interface SetPersistAction {
    type: typeof SET_PERSIST;
    payload: boolean;
}
export declare function setPersist(persist: boolean): SetPersistAction;
export interface ToggleSyncAction {
    type: typeof TOGGLE_SYNC;
}
export declare function toggleSync(): ToggleSyncAction;
export interface ToggleSliderAction {
    type: typeof TOGGLE_SLIDER;
}
export declare function toggleSlider(): ToggleSliderAction;
export interface ToggleDispatcherAction {
    type: typeof TOGGLE_DISPATCHER;
}
export declare function toggleDispatcher(): ToggleDispatcherAction;
interface Notification {
    readonly type: 'error';
    readonly message: string;
}
export interface ShowNotificationAction {
    readonly type: typeof SHOW_NOTIFICATION;
    readonly notification: Notification;
}
export declare function showNotification(message: string): ShowNotificationAction;
export interface ClearNotificationAction {
    readonly type: typeof CLEAR_NOTIFICATION;
}
export declare function clearNotification(): ClearNotificationAction;
export interface GetReportRequest {
    readonly type: typeof GET_REPORT_REQUEST;
    readonly report: unknown;
}
export declare function getReport(report: unknown): GetReportRequest;
export interface ActionCreator {
    args: string[];
    name: string;
}
export interface LibConfig {
    actionCreators?: string;
    name?: string;
    type?: string;
    features?: Features;
    serialize?: boolean;
}
export interface RequestBase {
    id?: string;
    instanceId?: string | number;
    action?: string;
    name?: string | undefined;
    libConfig?: LibConfig;
    actionsById?: string;
    computedStates?: string;
    payload?: {} | string;
    liftedState?: Partial<State>;
}
interface InitRequest extends RequestBase {
    type: 'INIT';
    action?: string;
    payload?: string;
}
interface ActionRequest extends RequestBase {
    type: 'ACTION';
    isExcess?: boolean;
    nextActionId: number;
    maxAge: number;
    batched?: boolean;
}
interface StateRequest extends RequestBase {
    type: 'STATE';
    committedState: unknown;
}
interface PartialStateRequest extends RequestBase {
    type: 'PARTIAL_STATE';
    committedState: unknown;
    maxAge: number;
}
interface LiftedRequest extends RequestBase {
    type: 'LIFTED';
}
export interface ExportRequest extends RequestBase {
    type: 'EXPORT';
    committedState: unknown;
}
export type Request = InitRequest | ActionRequest | StateRequest | PartialStateRequest | LiftedRequest | ExportRequest;
export interface UpdateStateAction {
    type: typeof UPDATE_STATE;
    request?: Request;
    id?: string | number;
}
export interface SetStateAction {
    type: typeof SET_STATE;
    newState: State;
}
export interface RemoveInstanceAction {
    type: typeof REMOVE_INSTANCE;
    id: string | number;
}
export interface ClearInstancesAction {
    type: typeof CLEAR_INSTANCES;
}
interface ListRequest {
    type: 'list';
    data: Data[];
}
interface AddRequest {
    type: 'add';
    data: Data;
}
interface RemoveRequest {
    type: 'remove';
    data: Data;
    id: unknown;
}
export type UpdateReportsRequest = ListRequest | AddRequest | RemoveRequest;
export interface UpdateReportsAction {
    type: typeof UPDATE_REPORTS;
    request: UpdateReportsRequest;
}
export interface GetReportError {
    type: typeof GET_REPORT_ERROR;
    error: Error;
}
export interface GetReportSuccess {
    type: typeof GET_REPORT_SUCCESS;
    data: {
        payload: string;
    };
}
export interface ErrorAction {
    type: typeof ERROR;
    payload: string;
}
export interface ReduxPersistRehydrateAction {
    type: typeof REHYDRATE;
    payload: unknown;
}
export type CoreStoreActionWithoutUpdateStateOrLiftedAction = ChangeSectionAction | ChangeThemeAction | ChangeStateTreeSettingsAction | MonitorActionAction | SelectInstanceAction | SelectMonitorAction | UpdateMonitorStateAction | ExportAction | TogglePersistAction | SetPersistAction | ToggleSyncAction | ToggleSliderAction | ToggleDispatcherAction | ShowNotificationAction | ClearNotificationAction | GetReportRequest | SetStateAction | RemoveInstanceAction | ClearInstancesAction | UpdateReportsAction | GetReportError | GetReportSuccess | ErrorAction | ReduxPersistRehydrateAction;
export type CoreStoreActionWithoutUpdateState = CoreStoreActionWithoutUpdateStateOrLiftedAction | LiftedActionAction;
export type CoreStoreActionWithoutLiftedAction = CoreStoreActionWithoutUpdateStateOrLiftedAction | UpdateStateAction;
export type CoreStoreAction = CoreStoreActionWithoutUpdateState | UpdateStateAction;
export {};
